@@ -21,12 +21,15 @@
 # with this program; if not, write to the Free Software Foundation,
 # Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 
-import os, string, shutil, time
+import os, string, shutil, time, sys
 
 class SpiritConvert:
 	NAME = "SpiritConvert"
-	PRESS = ["paperback"]
-	PROMPT = "Use which CafePress template: "
+	TEXS = [
+		"normal",
+		"paperback",
+		]
+	PROMPT = "Use which PDF template: "
 	
 	def __init__(self, debug, lib, consts):
 		self.debug = debug
@@ -36,12 +39,15 @@ class SpiritConvert:
 		self.RUBY2DIR = self.ROOT+os.sep+"user"+os.sep+"headers"
 		return
 
+	def which(self, files):
+		if len(files) > 1:
+			file = files[self.lib.choose(files, "Print which file: ")]
+		else:
+			file = files[0]
+		return file
+
 	def __prep(self, files):
-		for file in files:
-			if ((string.find(file,".fc") != -1) or 
-				(string.find(file,".sp") != -1)):
-				name = file
-				break
+		name = self.which(files)
 		shutil.copy(name, self.TEMP)
 		os.chdir(self.TEMP)
 		name = os.path.basename(name)
@@ -61,20 +67,31 @@ class SpiritConvert:
 		r.convert(name)
 		return name
 
-	def cafepress(self, files):
-		choice = self.lib.choose(self.PRESS, self.PROMPT)
-		latex = self.PRESS[choice]
+	def ps(self, files, pdf=0):
 		name = self.__prep(files)
-		shutil.copy(self.RUBY2DIR+os.sep+"header."+latex, self.TEMP)
+		##	latex = self.TEXS[self.lib.choose(self.TEXS, self.PROMPT)]
+		latex = "normal"
+		f = open(name)
+		line = f.readline()
+		f.close()
+		type = string.replace(string.strip(line),"*","")
+		shutil.copy(self.RUBY2DIR+os.sep+"header."+type, self.TEMP)
 		import ruby2latex
 		r = ruby2latex.ruby2latex()
-		r.convert(name, latex)
+		r.convert(name)
 		base = string.split(name,".")[0]
+		#convert tex to dvi
 		os.system("latex "+base+".tex")
+		#convert dvi to ps
 		if (latex == "paperback"):
 			os.system("dvips -T 5.0in,8.0in -o "+base+".ps "+base+".dvi")
-		os.system("ps2pdf "+base+".ps")
-		print "converted "+name+" to cafepress "+self.PRESS[choice]+" pdf" 
+		else:	
+			os.system("dvips -o "+base+".ps "+base+".dvi")
+		print "converted "+name+" to "+base+".ps"
+		#convert ps to pdf	
+		if pdf:	
+			os.system("ps2pdf "+base+".ps")
+			print "converted "+name+" to "+latex+" pdf" 
 
 	def service(self, params, options):
 		try:
@@ -86,7 +103,9 @@ class SpiritConvert:
 			elif (op == "t"):
 				self.text(files)
 			elif (op == "p"):
-				self.cafepress(files)
+				self.ps(files)
+			elif (op == "d"):
+				self.ps(files, 1)
 		except SystemExit:
 			pass
 		except:
