@@ -43,23 +43,18 @@ class SpiritPrint:
 		return(line[1:])
 
 	def dvi(self, name, files):
-		for file in files:
-			if (((string.find(file,name+".sp") != -1) or 
-				(string.find(file,name+".fc") != -1)
-				) and string.find(file,"~") == -1):
-				print file
-				type = self.get_type(file)
-				shutil.copy(file, self.TEMP)
-				shutil.copy(self.RUBY2DIR+os.sep+"header."+type, self.TEMP)
-				os.chdir(self.TEMP)
-				file = os.path.basename(file)
-				import ruby2latex
-				r = ruby2latex.ruby2latex()
-				r.convert(file)
-				name = ".".join(string.split(file,".")[:-1])
-				file = name+".tex"
-				os.system("latex " + file)
-				break
+		file = self.which(files)
+		type = self.get_type(file)
+		shutil.copy(file, self.TEMP)
+		shutil.copy(self.RUBY2DIR+os.sep+"header."+type, self.TEMP)
+		os.chdir(self.TEMP)
+		file = os.path.basename(file)
+		import ruby2latex
+		r = ruby2latex.ruby2latex()
+		r.convert(file)
+		name = ".".join(string.split(file,".")[:-1])
+		file = name+".tex"
+		os.system("latex " + file)
 		return
 
 	def draft_dvi(self,name):	
@@ -147,6 +142,13 @@ class SpiritPrint:
 				os.system("dvips -pp"+page+" "+file)
 		return
 
+	def which(self, files):
+		if len(files) > 1:
+			file = files[self.lib.choose(files, "Print which file: ")]
+		else:
+			file = files[0]
+		return file
+
 	def service(self, params, options):
 		try:
 			self.lib.checkdir(self.TEMP)		
@@ -164,12 +166,8 @@ class SpiritPrint:
 				files = self.lib.harvest(params[0])
 				self.draft(files[0])
 			elif (op == "b"):
-				files = self.lib.harvest(params[0])
-				if len(files) > 1:
-					file = self.lib.choose(files, "Print which file: ")
-				else:
-					file = 0
-				self.block(files[file])
+				file = self.which(self.lib.harvest(params[0]))
+				self.block(file)
 		except SystemExit:
 			pass
 		except:
