@@ -12,23 +12,28 @@ AUTHORS = "<!--authors-->"
 YEAR = "<!--year-->"
 CONTENT = "<!--content-->"
 COUNT = "<!--count-->"
-PAIRS = ["begin_quotation", "end_quotation",
-		 "begin_quote", "end_quote",
-		 "begin_verse", "end_verse", ]
+PAIRS = [
+##	"begin_quotation", "end_quotation",
+##	"begin_quote", "end_quote",
+	"begin_verse", "end_verse",
+	]
 TAGS     = {"part+:":["<p>&nbsp;<hr>\n<p>&nbsp;\n<h3>","</h3>\n<p>&nbsp;\n"],
 			"chapter+:":["<p>&nbsp;<hr align=left width=75%>\n<p>&nbsp;\n<h3>","</h3>\n<p>&nbsp;\n"],
 			"section+:":["<p>&nbsp;<hr align=left width=50%>\n<p>&nbsp;\n<h4>","</h4>\n<p>&nbsp;\n"],
 			"subsection+:":["<p>&nbsp;<hr align=left width=25%>\n<p>&nbsp;\n<h4>","</h4>\n"],
 			"paragraph":["\n<p>\n",""],
 			"frontmatter":["",""],
-			"begin_quotation":["<br><table width=70%><tr><td>&nbsp;&nbsp;</td><td><pre>\n",
-							   "</pre></td></tr></table>\n"],
+## 			"begin_quotation":["<br><table width=70%><tr><td>&nbsp;&nbsp;</td><td><pre>\n",
+## 							   "</pre></td></tr></table>\n"],
+			"begin_quotation":["<blockquote>","</blockquote>"],
 			"end_quotation":["",""],
-			"begin_quote":["<br><table width=70%><tr><td>&nbsp;&nbsp;</td><td><pre>\n",
-						   "</pre></td></tr></table>\n"],
+##			"begin_quote":["<br><table width=70%><tr><td>&nbsp;&nbsp;</td><td><pre>\n",
+##						   "</pre></td></tr></table>\n"],
+			"begin_quote":["<blockquote>","</blockquote>"],
 			"end_quote":["",""],
-			"begin_verse":["<br><table width=70%><tr><td>&nbsp;&nbsp;</td><td><pre>\n",
-						   "</pre></td></tr></table>\n"],
+##			"begin_verse":["<br><table width=70%><tr><td>&nbsp;&nbsp;</td><td><pre>\n",
+##						   "</pre></td></tr></table>\n"],
+			"begin_verse":["<blockquote>","</blockquote>"],
 			"end_verse":["",""],
 			"asterisks":["<p align=\"center\">***",""],
 			"---------":"---------",
@@ -161,11 +166,11 @@ class ruby2html:
 					style = string.replace(tokens[0],"*","")
 					if (string.find(style,"asterisks") != -1):
 						style = "asterisks"
-## 					if (style in PAIRS):
-## 						if (string.find(style,"begin") != -1):
-## 							newlines = 1
-## 						else:
-## 							newlines = 0
+					if (style in PAIRS):
+						if (string.find(style,"begin") != -1):
+							newlines = 1
+						else:
+							newlines = 0
 					try:		
 						content.append(TAGS[style][0])
 						if ((style in TWO_LINES) and
